pub fn simulation_module_any_to_pyobject(
py: Python<'_>,
module: &SimulationModuleAny,
) -> PyResult<Py<PyAny>>Expand description
Converts a declarative simulation module into its Python binding object.
Errors
Returns an error if the Python object cannot be allocated.