pub fn register_simulation_module_extractor<T: PyClass>(
py: Python<'_>,
extractor: SimulationModuleExtractor,
) -> Result<()>Expand description
Registers an extractor for a linked native simulation module Python class.
Registering the same function for the same Python type more than once succeeds without change.
Errors
Returns an error if a different extractor is already registered for T.